/************************************************************************
File Name:	div.asm

Date Modified:	05/22/00		GJO
				05/25/00		GJO	Code verified on rev 0.1 Silicon
				09/19/04		JDT Ported to VDSP++ 3.5

Description:	ADSP-21364 multichannel SIMD subroutine to compute the 
				quotient of its floating point inputs to single precision 
				accuracy (24 bits of mantissa).
				
				Equation:	QUO = NUM/DENOM

Calling Parameters:
			b0 = address of numerator
			b1 = address of quotient
			b12 = address of denominator
			l0,l1,l12 = 0 for modulo addressing
			m1 = 2
			m9 = 2

Assumptions:
			NUM and DENOM are 32-bit floating point representations

Return Values:
		    F0 = Quotient of inputs

Registers Affected:
		    F0, F7, F11, F12 

Cycle Count:
			6 cycles

Memory Usage:
			Instructions Words (48-bits):
				11 instruction words
			
			Data Words (16, 32, 40, or 64-bits):
				N locations for NUM in DM data and two for QUO (32-bits)
				N locations for DENOM in PM data (32-bits)

Notes: 
			
************************************************************************/

#include "def21364.h"

.GLOBAL divide;

.SECTION/PM     seg_pmco;

divide:        	bit set mode1 PEYEN ; 	/* Enable SIMD mode */
				nop;
				F11 = 2.0; 
				F0 = dm(i0,m1), F12 = pm(i12,m9);		/* Load PEx/PEy registers with DENOM data */	
				F0=RECIPS F12, F7=F0;       /* Get 4 bit seed R0=1/D */
                F12=F0*F12;             /* D(prime) = D*R0 */
                F7=F0*F7, F0=F11-F12;       /* F0=R1=2-D(prime), F7=N*R0 */
                F12=F0*F12;       		/* F12=D(prime)=D(prime)*R2 */
                F7=F0*F7, F0=F11-F12;       /* F7=N*R0*R1*R2, F0=R3=2-D(prime) */
				RTS (DB), F0=F0*F7;       	/* F0=N*R0*R1*R2*R3 */ 
				dm(i1,m1) = F0;			/* Store quotient into DM data */
				bit clr mode1 PEYEN ; 	/* Disable SIMD mode */


